@@ -3,6 +3,7 @@ import os
 from pathlib import Path
 
 import click
+import structlog
 from click import ClickException
 
 import hukudo.chromedriver
@@ -16,7 +17,7 @@ from .grafana.cli import grafana
     '-l',
     '--log-level',
     type=click.Choice(LOG_LEVELS, case_sensitive=False),
-    default=os.environ.get('LOGLEVEL', 'WARNING'),
+    default=lambda: os.environ.get('LOGLEVEL', 'WARNING'),
 )
 def root(log_level):
     """
@@ -28,12 +29,18 @@ def root(log_level):
     """
     configure_structlog_dev(log_level)
     logging.basicConfig(format='%(msg)s')
+    structlog.getLogger().debug('logging configured', level=log_level)
 
 
 # noinspection PyTypeChecker
 root.add_command(grafana)
 
 
+@root.command()
+def version():
+    print(hukudo.__version__)
+
+
 @root.group()
 def chromedriver():
     pass
@@ -57,7 +64,7 @@ def download(skip_symlink, force, target_dir):
     try:
         hukudo.chromedriver.download_and_symlink(target_dir, force=force, skip_symlink=skip_symlink)
     except HukudoException as e:
-        raise ClickException(e)
+        raise ClickException(str(e))
 
 
 def main():
