@@ -17,6 +17,10 @@ class JSONThing:
     def uid(self):
         return self.raw['uid']
 
+    @property
+    def title(self):
+        return self.raw['title']
+
 
 class Dashboard(JSONThing):
     def export(self, path):
